# archer
now

# dillian

local posts are propagated

boosts supported

DMs supported

# shine

no skipped tests

generated HTML for user pages

generated Atom for user pages

generated HTML for front page

# torquil

media upload

user fields

emojis

Mastodon protocol full coverage

# hathaway

HTML/JS for web client working

kepi.org.uk site working

basic dev docs

as few pylint errors as reasonably possible

# erskine

version 1.0

basic user docs

# venturus

posting via ActivityPub client to server

web client supports games etc

